@@ -7,11 +7,12 @@ use JSON::Any qw/XS DWIW JSON/;
 use URI::Escape;
 use HTTP::Request::Common;
 use Net::Twitter::Error;
+use Scalar::Util qw/reftype/;
 
 use namespace::autoclean;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.03003';
+our $VERSION = '3.04000';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
@@ -84,6 +85,10 @@ sub _from_json {
     return eval { JSON::Any->from_json($json) };
 }
 
+# By default, Net::Twitter does not inflate objects, so just return the
+# hashref, untouched. This is really just a hook for Role::InflateObjects.
+sub _inflate_objects { return $_[1] }
+
 sub _parse_result {
     my ($self, $res) = @_;
 
@@ -92,14 +97,13 @@ sub _parse_result {
     my $content = $res->content;
     $content =~ s/^"(true|false)"$/$1/;
 
-    # some JSON backends don't handle booleans correctly
-    # TODO: move this fix to JSON::Any
-    my $obj = $content eq 'true'  ? 1
-            : $content eq 'false' ? ''
-            : $self->_from_json($content);
+    my $obj = $self->_from_json($content);
+
+    # inflate the twitter object(s) if possible
+    $self->_inflate_objects($obj);
 
     # Twitter sometimes returns an error with status code 200
-    if ( $obj && ref $obj eq 'HASH' && exists $obj->{error} ) {
+    if ( ref $obj && reftype $obj eq 'HASH' && exists $obj->{error} ) {
         die Net::Twitter::Error->new(twitter_error => $obj, http_response => $res);
     }
 
@@ -111,9 +115,6 @@ sub _parse_result {
     die $error;
 }
 
-__PACKAGE__->meta->make_immutable;
-
-
 1;
 
 __END__
